@@ -785,6 +785,7 @@ TEST(ParserTest, mapEntries) {
     string sample_dir(CFG_EXAMPLES);
     sample_dir += "/";
     ElementPtr sample_json = Element::createList();
+    loadFile(sample_dir + "advanced.json", sample_json);
     loadFile(sample_dir + "all-keys.json", sample_json);
     loadFile(sample_dir + "reservations.json", sample_json);
     loadFile(sample_dir + "all-keys-netconf.json", sample_json);
@@ -828,6 +829,12 @@ TEST(ParserTest, mapEntries) {
         }
         return (s + " }");
     };
+    // Remove deprecated parameters. This needs to be done because even though
+    // they are supported, examples are loaded by yang tests also and they don't
+    // support both old and new syntax.
+    ASSERT_EQ(syntax_keys.erase("client-class"), 1);
+    ASSERT_EQ(syntax_keys.erase("only-if-required"), 1);
+    ASSERT_EQ(syntax_keys.erase("require-client-classes"), 1);
     EXPECT_EQ(syntax_keys, sample_keys)
         << "syntax has: " << print_keys(syntax_keys) << endl
         << "sample has: " << print_keys(sample_keys) << endl;
