@@ -1658,7 +1658,8 @@ TEST_F(HAConfigTest, badTrustAnchor) {
 #ifdef WITH_OPENSSL
     expected += "No such file or directory";
 #else
-    expected += "I/O error: DataSource: Failure opening file /this-file-does-not-exist";
+    expected += "I/O error: DataSource: Failure opening file ";
+    expected += "'/this-file-does-not-exist'";
 #endif
     testInvalidConfig(patched, expected);
 }
@@ -1698,7 +1699,8 @@ TEST_F(HAConfigTest, badCertFile) {
 #ifdef WITH_OPENSSL
     expected += "No such file or directory";
 #else
-    expected += "I/O error: DataSource: Failure opening file /this-file-does-not-exist";
+    expected += "I/O error: DataSource: Failure opening file ";
+    expected += "'/this-file-does-not-exist'";
 #endif
     testInvalidConfig(patched, expected);
 }
@@ -1738,7 +1740,8 @@ TEST_F(HAConfigTest, badKeyFile) {
 #ifdef WITH_OPENSSL
     expected += "No such file or directory";
 #else
-    expected += "I/O error: DataSource: Failure opening file /this-file-does-not-exist";
+    expected += "I/O error: DataSource: Failure opening file ";
+    expected += "'/this-file-does-not-exist'";
 #endif
     testInvalidConfig(patched, expected);
 }
