@@ -178,23 +178,22 @@ PingCheckMgr::startPing(dhcp::Lease4Ptr& lease, dhcp::Pkt4Ptr& query, hooks::Par
     startPing(lease, query, parking_lot, getGlobalConfig());
 }
 
-bool
-PingCheckMgr::nextToSend(IOAddress& next) {
-    if (checkSuspended()) {
-        return (false);
+PingContextPtr
+PingCheckMgr::nextToSend() {
+    if (!checkSuspended()) {
+        return (store_->getNextToSend());
     }
 
-    PingContextPtr context = store_->getNextToSend();
-    if (!context) {
-        return (false);
-    }
+    return (PingContextPtr());
+}
 
-    next = context->getTarget();
+void
+PingCheckMgr::updateContextToSend(PingContextPtr context) {
     // Transition to sending.
+    // Must not call @ref PingCheckMgr::checkSuspended() or
+    // it will cause a deadlock.
     context->setState(PingContext::SENDING);
     store_->updateContext(context);
-
-    return (true);
 }
 
 void
@@ -204,6 +203,8 @@ PingCheckMgr::sendCompleted(const ICMPMsgPtr& echo, bool send_failed) {
     }
 
     try {
+        MultiThreadingLock lock(*mutex_);
+
         if (!echo) {
             isc_throw(BadValue, "PingCheckMgr::sendCompleted() - echo is empty");
         }
@@ -231,7 +232,7 @@ PingCheckMgr::sendCompleted(const ICMPMsgPtr& echo, bool send_failed) {
         }
 
         // Update the expiration timer if necessary.
-        setNextExpiration();
+        setNextExpirationInternal();
     } catch (const std::exception& ex) {
         LOG_ERROR(ping_check_logger, PING_CHECK_MGR_SEND_COMPLETED_ERROR)
             .arg(ex.what());
@@ -245,6 +246,8 @@ PingCheckMgr::replyReceived(const ICMPMsgPtr& reply) {
     }
 
     try {
+        MultiThreadingLock lock(*mutex_);
+
         if (!reply) {
             isc_throw(BadValue, "PingCheckMgr::replyReceived() - echo is empty");
         }
@@ -262,7 +265,7 @@ PingCheckMgr::replyReceived(const ICMPMsgPtr& reply) {
             return;
         }
 
-        setNextExpiration();
+        setNextExpirationInternal();
     } catch (const std::exception& ex) {
         LOG_ERROR(ping_check_logger, PING_CHECK_MGR_REPLY_RECEIVED_ERROR)
             .arg(ex.what());
@@ -631,6 +634,8 @@ PingChannelPtr
 PingCheckMgr::createChannel(IOServicePtr io_service) {
     return (PingChannelPtr(new PingChannel(io_service,
                                            std::bind(&PingCheckMgr::nextToSend,
+                                                     this),
+                                           std::bind(&PingCheckMgr::updateContextToSend,
                                                      this, ph::_1),
                                            std::bind(&PingCheckMgr::sendCompleted,
                                                      this, ph::_1, ph::_2),
